@@ -554,7 +554,7 @@ class PilarTelescope(
         daz = float(await self._pilar.get("POSITION.INSTRUMENTAL.AZ.OFFSET"))
 
         # apply cos(alt) and return
-        return -dalt, float(daz * np.cos(np.radians(alt)))
+        return dalt, float(daz * np.cos(np.radians(alt)))
 
     @timeout(300000)
     async def init(self, **kwargs: Any) -> None:
@@ -707,6 +707,9 @@ class PilarTelescope(
         await self._pilar.safe_set("POINTING.MODEL.ADD", str(self._pointing_id), msg="Could not add measurement: ")
         self._pointing_id += 1
 
+        # save it
+        await self._pilar.safe_set("POINTING.MODEL.SAVE", 1)
+
         # get number of points
         log.info(f'Number of measurements: {await self._pilar.get("POINTING.MODEL.COUNT")}.')
 
